@@ -5,7 +5,7 @@ import subprocess
 from datetime import datetime, timedelta, timezone
 
 from prelude_sdk.controllers.detect_controller import DetectController
-from prelude_sdk.controllers.iam_controller import IAMController
+from prelude_sdk.controllers.iam_controller import IAMAccountController
 from prelude_sdk.controllers.probe_controller import ProbeController
 from prelude_sdk.models.codes import RunCode
 
@@ -15,7 +15,7 @@ from prelude_sdk.models.codes import RunCode
 class TestProbe:
 
     def setup_class(self):
-        self.iam = IAMController(pytest.account)
+        self.iam = IAMAccountController(pytest.account)
         self.detect = DetectController(pytest.account)
         self.probe = ProbeController(pytest.account)
 
@@ -23,8 +23,10 @@ class TestProbe:
         self.serial = "abc-123"
 
     def test_create_endpoint(self, unwrap):
-        pytest.token = unwrap(self.detect.register_endpoint)(
-            self.detect, host=self.host, serial_num=self.serial
+        pytest.token = self.detect.register_endpoint(
+            host=self.host,
+            serial_num=self.serial,
+            reg_string=f"{pytest.expected_account['account_id']}/{pytest.service_user_token}",
         )
 
         res = unwrap(self.detect.list_endpoints)(self.detect)
